@@ -76,7 +76,7 @@ class Witter():
             "on_timeline_clicked" : self.switchView,
             "on_mentions_clicked" : self.switchView,
             "on_direct_messages_clicked" : self.switchView,
-            "on_public_clicked" : self.switchView,
+            "on_search_clicked" : self.switchView,
             "on_trend_clicked" : self.switchView,
             "on_insert_clicked" : self.twitPic,
             "on_friends_clicked" : self.switchView,
@@ -91,29 +91,36 @@ class Witter():
         #yet to store uid/pwd so for the moment just put info here
         
         
+        #at one point I had the text different colours
+        #I may do again
+        self.namecolour = self.textcolour
+        self.tweetcolour = self.textcolour
         
-        self.namecolour = "#2E00B8"
-        self.tweetcolour = "#000000"
         self.defaultwidth = 500
         #default to colours above, but check if we're on fremantle and change
         #to appropriate colours if we are
         self.checkVersion()
         #This being a hildon app we start with a hildon.Window
-        self.window = hildon.Window()
+        self.window = hildon.StackableWindow()
+
         #connect the delete event for closing the window
         self.window.connect("delete_event", self.quit)
         #add window to self  
         self.program.add_window(self.window)
         #reparent the vbox1 from glade to self.window
         self.vbox = self.wTree.get_widget("vbox1")
-        self.scrolled_window = self.wTree.get_widget("scrolled_window")
-        self.vbox.reparent(self.window)
+        pannedWindow = hildon.PannableArea()
+        # hildon.hildon_pannable_area_new_full(mode, enabled, vel_min, vel_max, decel, sps)
 
+        #self.scrolled_window = self.wTree.get_widget("scrolled_window")
+        self.vbox.reparent(self.window)
+        self.vbox.pack_end(pannedWindow)
+        
         self.urlmenu = self.build_right_click_menu()
         # create a menu object by calling a method to deine it
-        self.menu = self.create_menu(self.scrolled_window)
+        self.menu = self.create_m5_menu(self)
         # add the menu to the window
-        self.window.set_menu(self.menu)
+        self.window.set_app_menu(self.menu)
         #
         
         
@@ -194,7 +201,7 @@ class Witter():
         # I don't want to accidentally be dragging and dropping rows out of order
         self.treeview.set_reorderable(False)
         #with all that done I add the treeview to the scrolled window
-        self.scrolled_window.add(self.treeview)
+        pannedWindow.add_with_viewport(self.treeview)
         #self.treeview.connect("button-press-event", self.build_menu, None);
         selection = self.treeview.get_selection()
         selection.connect('changed', self.build_menu)
@@ -209,6 +216,7 @@ class Witter():
     def quit(self, *args):
         #this is our end method called when window is closed
         print "Stop Wittering"
+        self.writeConfig()
         gtk.main_quit()
        
     def create_menu(self, widget):
@@ -229,6 +237,8 @@ class Witter():
         menuItemPublic.connect("activate", self.switchViewTo, "public")
         menuItemCreds = gtk.MenuItem("Set UID/PWD")
         menuItemCreds.connect("activate",self.promptForCredentials)
+        menuItemInvert = gtk.MenuItem("Invert Text")
+        menuItemInvert.connect("activate",self.flipTextColour)
         menuItemSeparator = gtk.SeparatorMenuItem()
         menuItemExit = gtk.MenuItem("Exit")
         menuItemExit.connect("activate", self.quit);
@@ -245,6 +255,72 @@ class Witter():
         menuItemFile = gtk.MenuItem("File")
         menuItemFile.set_submenu(menu)
         return menu
+
+ 
+    def create_m5_menu(self, widget):
+        #a fairly standard menu create
+        #I put in the same options as I have buttons
+        # and linked to the same methods
+        menu = hildon.AppMenu()
+
+        GetTweets = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        command_id = "Get Tweets"
+        GetTweets.set_label(command_id)
+        # Attach callback to clicked signal
+        GetTweets.connect("clicked", self.getTweets)
+        GetTweets.show()
+        menu.append(GetTweets)
+        Tweets = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        Tweets.set_label("Tweet")
+        # Attach callback to clicked signal
+        Tweets.connect("clicked", self.newTweet)
+        Tweets.show()
+        menu.append(Tweets)
+        
+        TwitPic = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        TwitPic.set_label("TwitPic!")
+        # Attach callback to clicked signal
+        TwitPic.connect("clicked", self.selectImage)
+        TwitPic.show()
+        menu.append(TwitPic)
+        
+        Trends = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        Trends.set_label("Trends")
+        # Attach callback to clicked signal
+        Trends.connect("clicked", self.switchViewTo, "trends")
+        Trends.show()
+        menu.append(Trends)
+        
+        Public = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        Public.set_label("Public")
+        # Attach callback to clicked signal
+        Public.connect("clicked", self.switchViewTo, "public")
+        Public.show()
+        menu.append(Public)
+        
+        Creds = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        Creds.set_label("Set UID/PWD")
+        # Attach callback to clicked signal
+        Creds.connect("clicked", self.promptForCredentials)
+        Creds.show()
+        menu.append(Creds)
+        
+        Invert = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        Invert.set_label("Invert")
+        # Attach callback to clicked signal
+        Invert.connect("clicked", self.flipTextColour)
+        Invert.show()
+        menu.append(Invert)
+        
+        Exit = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        Exit.set_label("Exit")
+        # Attach callback to clicked signal
+        Exit.connect("clicked", self.quit)
+        Exit.show()
+        menu.append(Exit)
+        
+        menu.show_all()
+        return menu
  
     def run(self):     
         #this is the main execution method
@@ -783,7 +859,10 @@ class Witter():
             self.username=base64.b64decode(user)
             password = config.get("credentials", "password");
             self.password=base64.b64decode(password)
-            
+            try:
+                self.textcolour=config.get("UI","textcolour")
+            except ConfigParser.NoSectionError:
+                print "no text colour setting"
         except IOError:
             #couldn't find the file set uid/pwd to empty values
             self.username = ""
@@ -796,7 +875,8 @@ class Witter():
         f.write("[credentials]\n")
         f.write("username = "+base64.b64encode(self.username)+"\n")
         f.write("password = "+base64.b64encode(self.password)+"\n")    
-        
+        f.write("[UI]\n")
+        f.write("textcolour = "+self.textcolour+"\n")
     def promptForCredentials(self, *args):
         dialog = self.wTree.get_widget("CredentialsDialog")
         dialog.set_title("Twitter Credentials")
@@ -855,6 +935,62 @@ class Witter():
         imageChose.set_filter(filter)
         imageChose.connect("response", self.gtk_widget_hide)
         imageChose.show()
+        
+    def flipTextColour(self, *args):
+        #until I figure out how to obey theme colours, let the user
+        #flip the colours in use.
+        if (re.search("#000000", self.textcolour)):
+            self.textcolour = "#FFFFFF"
+            
+        else:
+            self.textcolour = "#000000"
+        #reset all the values in the current list stores
+        item = self.liststore.get_iter_first ()
+
+        while ( item != None ):
+            self.liststore.set_value(item,1,self.textcolour)
+            self.liststore.set_value(item,3,self.textcolour)
+            item = self.liststore.iter_next(item)
+        
+        item = self.dmliststore.get_iter_first ()
+
+        while ( item != None ):
+            self.dmliststore.set_value(item,1,self.textcolour)
+            self.dmliststore.set_value(item,3,self.textcolour)
+            item = self.dmliststore.iter_next(item)
+        item = self.friendsliststore.get_iter_first ()
+
+        while ( item != None ):
+            self.friendsliststore.set_value(item,1,self.textcolour)
+            self.friendsliststore.set_value(item,3,self.textcolour)
+            item = self.friendsliststore.iter_next(item)
+        
+        item = self.mentionliststore.get_iter_first ()
+
+        while ( item != None ):
+            self.mentionliststore.set_value(item,1,self.textcolour)
+            self.mentionliststore.set_value(item,3,self.textcolour)
+            item = self.mentionliststore.iter_next(item)
+        item = self.publicliststore.get_iter_first ()
+
+        while ( item != None ):
+            self.publicliststore.set_value(item,1,self.textcolour)
+            self.publicliststore.set_value(item,3,self.textcolour)
+            item = self.publicliststore.iter_next(item)
+        
+        item = self.searchliststore.get_iter_first ()
+
+        while ( item != None ):
+            self.searchliststore.set_value(item,1,self.textcolour)
+            self.searchliststore.set_value(item,3,self.textcolour)
+            item = self.searchliststore.iter_next(item)
+            
+        item = self.trendliststore.get_iter_first ()
+
+        while ( item != None ):
+            self.trendliststore.set_value(item,1,self.textcolour)
+            self.trendliststore.set_value(item,3,self.textcolour)
+            item = self.trendliststore.iter_next(item)
       
     def twitPic(self, widget, *args):
         print "twitPic"
